Document `OVERRIDE_TARGET_FLATTEN_APEX` in ART documentation.

If one wants to forcibly enable/disable APEX flattening, they should
now use `OVERRIDE_TARGET_FLATTEN_APEX` instead of
`TARGET_FLATTEN_APEX` (which has stopped working lately).

Test: n/a (documentation-only change)
Bug: 121117762

Change-Id: I4d865eaf13e29c860e71f8c5fafad67fcd6db4b0
diff --git a/test/README.chroot.md b/test/README.chroot.md
index d2fb4c9..ccba266 100644
--- a/test/README.chroot.md
+++ b/test/README.chroot.md
@@ -58,6 +58,7 @@
         ```
     * With a full Android (AOSP) `aosp/master` tree:
         ```bash
+        export OVERRIDE_TARGET_FLATTEN_APEX=true
         . ./build/envsetup.sh
         lunch aosp_arm64-eng  # or aosp_arm-eng for 32-bit ARM
         m adb
diff --git a/tools/buildbot-sync.sh b/tools/buildbot-sync.sh
index 6c803b6..fb59272 100755
--- a/tools/buildbot-sync.sh
+++ b/tools/buildbot-sync.sh
@@ -43,7 +43,8 @@
   echo -e "${red}This script only works when  APEX packages are flattened, but the build" \
     "configuration is set up to use non-flattened APEX packages.${nc}"
   echo -e "${magenta}You can force APEX flattening by setting the environment variable" \
-    "\`TARGET_FLATTEN_APEX\` to \"true\" before starting the build and running this script.${nc}"
+    "\`OVERRIDE_TARGET_FLATTEN_APEX\` to \"true\" before starting the build and running this" \
+    "script.${nc}"
   exit 1
 fi
 
@@ -146,7 +147,7 @@
 # chroot. $2 defaults to $1.
 #
 # TODO: Handle the case of build targets using non-flatted APEX packages.
 # As a workaround, one can run `export TARGET_FLATTEN_APEX=true` before building
 # a target to have its APEX packages flattened.
 activate_apex() {
   local src_apex=${1}
@@ -146,7 +147,7 @@
 #
 # TODO: Handle the case of build targets using non-flatted APEX packages.
-# As a workaround, one can run `export TARGET_FLATTEN_APEX=true` before building
+# As a workaround, one can run `export OVERRIDE_TARGET_FLATTEN_APEX=true` before building
 # a target to have its APEX packages flattened.
 activate_apex() {